
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "ephy-lib-type-builtins.h"
#include "ephy-adaptive-mode.h"
#include "ephy-permissions-manager.h"
#include "ephy-prefs.h"
#include "ephy-security-levels.h"
#include "ephy-sqlite-connection.h"
#include "history/ephy-history-types.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "ephy-adaptive-mode.h" */

GType
ephy_adaptive_mode_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_ADAPTIVE_MODE_NARROW), "EPHY_ADAPTIVE_MODE_NARROW", "narrow" },
        { C_ENUM (EPHY_ADAPTIVE_MODE_NORMAL), "EPHY_ADAPTIVE_MODE_NORMAL", "normal" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyAdaptiveMode"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-permissions-manager.h" */

GType
ephy_permission_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_PERMISSION_UNDECIDED), "EPHY_PERMISSION_UNDECIDED", "undecided" },
        { C_ENUM (EPHY_PERMISSION_DENY), "EPHY_PERMISSION_DENY", "deny" },
        { C_ENUM (EPHY_PERMISSION_PERMIT), "EPHY_PERMISSION_PERMIT", "permit" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyPermission"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_permission_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_PERMISSION_TYPE_SHOW_NOTIFICATIONS), "EPHY_PERMISSION_TYPE_SHOW_NOTIFICATIONS", "show-notifications" },
        { C_ENUM (EPHY_PERMISSION_TYPE_SAVE_PASSWORD), "EPHY_PERMISSION_TYPE_SAVE_PASSWORD", "save-password" },
        { C_ENUM (EPHY_PERMISSION_TYPE_ACCESS_LOCATION), "EPHY_PERMISSION_TYPE_ACCESS_LOCATION", "access-location" },
        { C_ENUM (EPHY_PERMISSION_TYPE_ACCESS_MICROPHONE), "EPHY_PERMISSION_TYPE_ACCESS_MICROPHONE", "access-microphone" },
        { C_ENUM (EPHY_PERMISSION_TYPE_ACCESS_WEBCAM), "EPHY_PERMISSION_TYPE_ACCESS_WEBCAM", "access-webcam" },
        { C_ENUM (EPHY_PERMISSION_TYPE_SHOW_ADS), "EPHY_PERMISSION_TYPE_SHOW_ADS", "show-ads" },
        { C_ENUM (EPHY_PERMISSION_TYPE_AUTOPLAY_POLICY), "EPHY_PERMISSION_TYPE_AUTOPLAY_POLICY", "autoplay-policy" },
        { C_ENUM (EPHY_PERMISSION_TYPE_ACCESS_WEBCAM_AND_MICROPHONE), "EPHY_PERMISSION_TYPE_ACCESS_WEBCAM_AND_MICROPHONE", "access-webcam-and-microphone" },
        { C_ENUM (EPHY_PERMISSION_TYPE_WEBSITE_DATA_ACCESS), "EPHY_PERMISSION_TYPE_WEBSITE_DATA_ACCESS", "website-data-access" },
        { C_ENUM (EPHY_PERMISSION_TYPE_CLIPBOARD), "EPHY_PERMISSION_TYPE_CLIPBOARD", "clipboard" },
        { C_ENUM (EPHY_PERMISSION_TYPE_ACCESS_DISPLAY), "EPHY_PERMISSION_TYPE_ACCESS_DISPLAY", "access-display" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyPermissionType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-prefs.h" */

GType
ephy_prefs_reader_font_style_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_PREFS_READER_FONT_STYLE_SANS), "EPHY_PREFS_READER_FONT_STYLE_SANS", "sans" },
        { C_ENUM (EPHY_PREFS_READER_FONT_STYLE_SERIF), "EPHY_PREFS_READER_FONT_STYLE_SERIF", "serif" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyPrefsReaderFontStyle"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_prefs_reader_color_scheme_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_PREFS_READER_COLORS_LIGHT), "EPHY_PREFS_READER_COLORS_LIGHT", "light" },
        { C_ENUM (EPHY_PREFS_READER_COLORS_DARK), "EPHY_PREFS_READER_COLORS_DARK", "dark" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyPrefsReaderColorScheme"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_prefs_restore_session_policy_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_PREFS_RESTORE_SESSION_POLICY_ALWAYS), "EPHY_PREFS_RESTORE_SESSION_POLICY_ALWAYS", "always" },
        { C_ENUM (EPHY_PREFS_RESTORE_SESSION_POLICY_CRASHED), "EPHY_PREFS_RESTORE_SESSION_POLICY_CRASHED", "crashed" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyPrefsRestoreSessionPolicy"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_prefs_ui_tabs_bar_visibility_policy_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_ALWAYS), "EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_ALWAYS", "always" },
        { C_ENUM (EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_MORE_THAN_ONE), "EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_MORE_THAN_ONE", "more-than-one" },
        { C_ENUM (EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_NEVER), "EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_NEVER", "never" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyPrefsUITabsBarVisibilityPolicy"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_prefs_web_hardware_acceleration_policy_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ALWAYS), "EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ALWAYS", "always" },
        { C_ENUM (EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_NEVER), "EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_NEVER", "never" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyPrefsWebHardwareAccelerationPolicy"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-security-levels.h" */

GType
ephy_security_level_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_SECURITY_LEVEL_TO_BE_DETERMINED), "EPHY_SECURITY_LEVEL_TO_BE_DETERMINED", "to-be-determined" },
        { C_ENUM (EPHY_SECURITY_LEVEL_NO_SECURITY), "EPHY_SECURITY_LEVEL_NO_SECURITY", "no-security" },
        { C_ENUM (EPHY_SECURITY_LEVEL_UNACCEPTABLE_CERTIFICATE), "EPHY_SECURITY_LEVEL_UNACCEPTABLE_CERTIFICATE", "unacceptable-certificate" },
        { C_ENUM (EPHY_SECURITY_LEVEL_MIXED_CONTENT), "EPHY_SECURITY_LEVEL_MIXED_CONTENT", "mixed-content" },
        { C_ENUM (EPHY_SECURITY_LEVEL_STRONG_SECURITY), "EPHY_SECURITY_LEVEL_STRONG_SECURITY", "strong-security" },
        { C_ENUM (EPHY_SECURITY_LEVEL_LOCAL_PAGE), "EPHY_SECURITY_LEVEL_LOCAL_PAGE", "local-page" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphySecurityLevel"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-sqlite-connection.h" */

GType
ephy_sq_lite_connection_mode_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_SQLITE_CONNECTION_MODE_MEMORY), "EPHY_SQLITE_CONNECTION_MODE_MEMORY", "memory" },
        { C_ENUM (EPHY_SQLITE_CONNECTION_MODE_READWRITE), "EPHY_SQLITE_CONNECTION_MODE_READWRITE", "readwrite" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphySQLiteConnectionMode"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_sq_lite_statement_lifetime_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_SQLITE_STATEMENT_SHORT_LIVED), "EPHY_SQLITE_STATEMENT_SHORT_LIVED", "short-lived" },
        { C_ENUM (EPHY_SQLITE_STATEMENT_LONG_LIVED), "EPHY_SQLITE_STATEMENT_LONG_LIVED", "long-lived" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphySQLiteStatementLifetime"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-history-types.h" */

GType
ephy_history_page_visit_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_PAGE_VISIT_NONE), "EPHY_PAGE_VISIT_NONE", "none" },
        { C_ENUM (EPHY_PAGE_VISIT_LINK), "EPHY_PAGE_VISIT_LINK", "link" },
        { C_ENUM (EPHY_PAGE_VISIT_TYPED), "EPHY_PAGE_VISIT_TYPED", "typed" },
        { C_ENUM (EPHY_PAGE_VISIT_BOOKMARK), "EPHY_PAGE_VISIT_BOOKMARK", "bookmark" },
        { C_ENUM (EPHY_PAGE_VISIT_HOMEPAGE), "EPHY_PAGE_VISIT_HOMEPAGE", "homepage" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyHistoryPageVisitType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_history_url_property_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_HISTORY_URL_TITLE), "EPHY_HISTORY_URL_TITLE", "title" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyHistoryURLProperty"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_history_sort_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_HISTORY_SORT_NONE), "EPHY_HISTORY_SORT_NONE", "none" },
        { C_ENUM (EPHY_HISTORY_SORT_MOST_RECENTLY_VISITED), "EPHY_HISTORY_SORT_MOST_RECENTLY_VISITED", "most-recently-visited" },
        { C_ENUM (EPHY_HISTORY_SORT_LEAST_RECENTLY_VISITED), "EPHY_HISTORY_SORT_LEAST_RECENTLY_VISITED", "least-recently-visited" },
        { C_ENUM (EPHY_HISTORY_SORT_MOST_VISITED), "EPHY_HISTORY_SORT_MOST_VISITED", "most-visited" },
        { C_ENUM (EPHY_HISTORY_SORT_LEAST_VISITED), "EPHY_HISTORY_SORT_LEAST_VISITED", "least-visited" },
        { C_ENUM (EPHY_HISTORY_SORT_TITLE_ASCENDING), "EPHY_HISTORY_SORT_TITLE_ASCENDING", "title-ascending" },
        { C_ENUM (EPHY_HISTORY_SORT_TITLE_DESCENDING), "EPHY_HISTORY_SORT_TITLE_DESCENDING", "title-descending" },
        { C_ENUM (EPHY_HISTORY_SORT_URL_ASCENDING), "EPHY_HISTORY_SORT_URL_ASCENDING", "url-ascending" },
        { C_ENUM (EPHY_HISTORY_SORT_URL_DESCENDING), "EPHY_HISTORY_SORT_URL_DESCENDING", "url-descending" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyHistorySortType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* Generated data ends here */

