
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "ephy-adaptive-mode.h" */

GType ephy_adaptive_mode_get_type (void);
#define EPHY_TYPE_ADAPTIVE_MODE (ephy_adaptive_mode_get_type())

/* enumerations from "ephy-permissions-manager.h" */

GType ephy_permission_get_type (void);
#define EPHY_TYPE_PERMISSION (ephy_permission_get_type())

GType ephy_permission_type_get_type (void);
#define EPHY_TYPE_PERMISSION_TYPE (ephy_permission_type_get_type())

/* enumerations from "ephy-prefs.h" */

GType ephy_prefs_reader_font_style_get_type (void);
#define EPHY_TYPE_PREFS_READER_FONT_STYLE (ephy_prefs_reader_font_style_get_type())

GType ephy_prefs_reader_color_scheme_get_type (void);
#define EPHY_TYPE_PREFS_READER_COLOR_SCHEME (ephy_prefs_reader_color_scheme_get_type())

GType ephy_prefs_restore_session_policy_get_type (void);
#define EPHY_TYPE_PREFS_RESTORE_SESSION_POLICY (ephy_prefs_restore_session_policy_get_type())

GType ephy_prefs_ui_tabs_bar_visibility_policy_get_type (void);
#define EPHY_TYPE_PREFS_UI_TABS_BAR_VISIBILITY_POLICY (ephy_prefs_ui_tabs_bar_visibility_policy_get_type())

GType ephy_prefs_web_hardware_acceleration_policy_get_type (void);
#define EPHY_TYPE_PREFS_WEB_HARDWARE_ACCELERATION_POLICY (ephy_prefs_web_hardware_acceleration_policy_get_type())

/* enumerations from "ephy-security-levels.h" */

GType ephy_security_level_get_type (void);
#define EPHY_TYPE_SECURITY_LEVEL (ephy_security_level_get_type())

/* enumerations from "ephy-sqlite-connection.h" */

GType ephy_sq_lite_connection_mode_get_type (void);
#define EPHY_TYPE_SQ_LITE_CONNECTION_MODE (ephy_sq_lite_connection_mode_get_type())

GType ephy_sq_lite_statement_lifetime_get_type (void);
#define EPHY_TYPE_SQ_LITE_STATEMENT_LIFETIME (ephy_sq_lite_statement_lifetime_get_type())

/* enumerations from "ephy-history-types.h" */

GType ephy_history_page_visit_type_get_type (void);
#define EPHY_TYPE_HISTORY_PAGE_VISIT_TYPE (ephy_history_page_visit_type_get_type())

GType ephy_history_url_property_get_type (void);
#define EPHY_TYPE_HISTORY_URL_PROPERTY (ephy_history_url_property_get_type())

GType ephy_history_sort_type_get_type (void);
#define EPHY_TYPE_HISTORY_SORT_TYPE (ephy_history_sort_type_get_type())

G_END_DECLS

/* Generated data ends here */

