
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "ephy-type-builtins.h"
#include "bookmarks/ephy-bookmark-properties.h"
#include "ephy-link.h"
#include "ephy-session.h"
#include "ephy-shell.h"
#include "ephy-window.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "ephy-link.h" */

GType
ephy_link_flags_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (EPHY_LINK_NEW_WINDOW), "EPHY_LINK_NEW_WINDOW", "new-window" },
        { C_FLAGS (EPHY_LINK_NEW_TAB), "EPHY_LINK_NEW_TAB", "new-tab" },
        { C_FLAGS (EPHY_LINK_JUMP_TO), "EPHY_LINK_JUMP_TO", "jump-to" },
        { C_FLAGS (EPHY_LINK_NEW_TAB_APPEND_AFTER), "EPHY_LINK_NEW_TAB_APPEND_AFTER", "new-tab-append-after" },
        { C_FLAGS (EPHY_LINK_HOME_PAGE), "EPHY_LINK_HOME_PAGE", "home-page" },
        { C_FLAGS (EPHY_LINK_TYPED), "EPHY_LINK_TYPED", "typed" },
        { C_FLAGS (EPHY_LINK_BOOKMARK), "EPHY_LINK_BOOKMARK", "bookmark" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("EphyLinkFlags"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-shell.h" */

GType
ephy_new_tab_flags_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (EPHY_NEW_TAB_DONT_SHOW_WINDOW), "EPHY_NEW_TAB_DONT_SHOW_WINDOW", "dont-show-window" },
        { C_FLAGS (EPHY_NEW_TAB_FIRST), "EPHY_NEW_TAB_FIRST", "first" },
        { C_FLAGS (EPHY_NEW_TAB_APPEND_LAST), "EPHY_NEW_TAB_APPEND_LAST", "append-last" },
        { C_FLAGS (EPHY_NEW_TAB_APPEND_AFTER), "EPHY_NEW_TAB_APPEND_AFTER", "append-after" },
        { C_FLAGS (EPHY_NEW_TAB_JUMP), "EPHY_NEW_TAB_JUMP", "jump" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("EphyNewTabFlags"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_startup_mode_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_STARTUP_NEW_TAB), "EPHY_STARTUP_NEW_TAB", "tab" },
        { C_ENUM (EPHY_STARTUP_NEW_WINDOW), "EPHY_STARTUP_NEW_WINDOW", "window" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyStartupMode"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-window.h" */

GType
ephy_window_chrome_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (EPHY_WINDOW_CHROME_HEADER_BAR), "EPHY_WINDOW_CHROME_HEADER_BAR", "header-bar" },
        { C_FLAGS (EPHY_WINDOW_CHROME_MENU), "EPHY_WINDOW_CHROME_MENU", "menu" },
        { C_FLAGS (EPHY_WINDOW_CHROME_LOCATION), "EPHY_WINDOW_CHROME_LOCATION", "location" },
        { C_FLAGS (EPHY_WINDOW_CHROME_TABSBAR), "EPHY_WINDOW_CHROME_TABSBAR", "tabsbar" },
        { C_FLAGS (EPHY_WINDOW_CHROME_BOOKMARKS), "EPHY_WINDOW_CHROME_BOOKMARKS", "bookmarks" },
        { C_FLAGS (EPHY_WINDOW_CHROME_DEFAULT), "EPHY_WINDOW_CHROME_DEFAULT", "default" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("EphyWindowChrome"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* Generated data ends here */

