
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "ephy-embed-type-builtins.h"
#include "ephy-download.h"
#include "ephy-embed-shell.h"
#include "ephy-search-entry.h"
#include "ephy-web-view.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "ephy-download.h" */

GType
ephy_download_action_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_DOWNLOAD_ACTION_NONE), "EPHY_DOWNLOAD_ACTION_NONE", "none" },
        { C_ENUM (EPHY_DOWNLOAD_ACTION_BROWSE_TO), "EPHY_DOWNLOAD_ACTION_BROWSE_TO", "browse-to" },
        { C_ENUM (EPHY_DOWNLOAD_ACTION_OPEN), "EPHY_DOWNLOAD_ACTION_OPEN", "open" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyDownloadActionType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-embed-shell.h" */

GType
ephy_embed_shell_mode_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_EMBED_SHELL_MODE_BROWSER), "EPHY_EMBED_SHELL_MODE_BROWSER", "browser" },
        { C_ENUM (EPHY_EMBED_SHELL_MODE_STANDALONE), "EPHY_EMBED_SHELL_MODE_STANDALONE", "standalone" },
        { C_ENUM (EPHY_EMBED_SHELL_MODE_PRIVATE), "EPHY_EMBED_SHELL_MODE_PRIVATE", "private" },
        { C_ENUM (EPHY_EMBED_SHELL_MODE_INCOGNITO), "EPHY_EMBED_SHELL_MODE_INCOGNITO", "incognito" },
        { C_ENUM (EPHY_EMBED_SHELL_MODE_APPLICATION), "EPHY_EMBED_SHELL_MODE_APPLICATION", "application" },
        { C_ENUM (EPHY_EMBED_SHELL_MODE_TEST), "EPHY_EMBED_SHELL_MODE_TEST", "test" },
        { C_ENUM (EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER), "EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER", "search-provider" },
        { C_ENUM (EPHY_EMBED_SHELL_MODE_AUTOMATION), "EPHY_EMBED_SHELL_MODE_AUTOMATION", "automation" },
        { C_ENUM (EPHY_EMBED_SHELL_MODE_KIOSK), "EPHY_EMBED_SHELL_MODE_KIOSK", "kiosk" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyEmbedShellMode"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-search-entry.h" */

GType
ephy_find_result_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_FIND_RESULT_FOUND), "EPHY_FIND_RESULT_FOUND", "found" },
        { C_ENUM (EPHY_FIND_RESULT_NOTFOUND), "EPHY_FIND_RESULT_NOTFOUND", "notfound" },
        { C_ENUM (EPHY_FIND_RESULT_FOUNDWRAPPED), "EPHY_FIND_RESULT_FOUNDWRAPPED", "foundwrapped" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyFindResult"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "ephy-web-view.h" */

GType
ephy_web_view_navigation_flags_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (EPHY_WEB_VIEW_NAV_BACK), "EPHY_WEB_VIEW_NAV_BACK", "back" },
        { C_FLAGS (EPHY_WEB_VIEW_NAV_FORWARD), "EPHY_WEB_VIEW_NAV_FORWARD", "forward" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("EphyWebViewNavigationFlags"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_web_view_document_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_WEB_VIEW_DOCUMENT_HTML), "EPHY_WEB_VIEW_DOCUMENT_HTML", "html" },
        { C_ENUM (EPHY_WEB_VIEW_DOCUMENT_XML), "EPHY_WEB_VIEW_DOCUMENT_XML", "xml" },
        { C_ENUM (EPHY_WEB_VIEW_DOCUMENT_IMAGE), "EPHY_WEB_VIEW_DOCUMENT_IMAGE", "image" },
        { C_ENUM (EPHY_WEB_VIEW_DOCUMENT_OTHER), "EPHY_WEB_VIEW_DOCUMENT_OTHER", "other" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyWebViewDocumentType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_web_view_error_page_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_WEB_VIEW_ERROR_PAGE_NONE), "EPHY_WEB_VIEW_ERROR_PAGE_NONE", "page-none" },
        { C_ENUM (EPHY_WEB_VIEW_ERROR_PAGE_NETWORK_ERROR), "EPHY_WEB_VIEW_ERROR_PAGE_NETWORK_ERROR", "page-network-error" },
        { C_ENUM (EPHY_WEB_VIEW_ERROR_PAGE_CRASH), "EPHY_WEB_VIEW_ERROR_PAGE_CRASH", "page-crash" },
        { C_ENUM (EPHY_WEB_VIEW_ERROR_PROCESS_CRASH), "EPHY_WEB_VIEW_ERROR_PROCESS_CRASH", "process-crash" },
        { C_ENUM (EPHY_WEB_VIEW_ERROR_UNRESPONSIVE_PROCESS), "EPHY_WEB_VIEW_ERROR_UNRESPONSIVE_PROCESS", "unresponsive-process" },
        { C_ENUM (EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE), "EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE", "invalid-tls-certificate" },
        { C_ENUM (EPHY_WEB_VIEW_ERROR_NO_SUCH_FILE), "EPHY_WEB_VIEW_ERROR_NO_SUCH_FILE", "no-such-file" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyWebViewErrorPage"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_web_view_message_handler_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (EPHY_WEB_VIEW_TLS_ERROR_PAGE_MESSAGE_HANDLER), "EPHY_WEB_VIEW_TLS_ERROR_PAGE_MESSAGE_HANDLER", "tls-error-page-message-handler" },
        { C_FLAGS (EPHY_WEB_VIEW_RELOAD_PAGE_MESSAGE_HANDLER), "EPHY_WEB_VIEW_RELOAD_PAGE_MESSAGE_HANDLER", "reload-page-message-handler" },
        { C_FLAGS (EPHY_WEB_VIEW_ABOUT_APPS_MESSAGE_HANDLER), "EPHY_WEB_VIEW_ABOUT_APPS_MESSAGE_HANDLER", "about-apps-message-handler" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("EphyWebViewMessageHandler"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
ephy_web_view_message_handler_scope_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (EPHY_WEB_VIEW_REGISTER_MESSAGE_HANDLER_FOR_CURRENT_PAGE), "EPHY_WEB_VIEW_REGISTER_MESSAGE_HANDLER_FOR_CURRENT_PAGE", "current-page" },
        { C_ENUM (EPHY_WEB_VIEW_REGISTER_MESSAGE_HANDLER_FOR_NEXT_LOAD), "EPHY_WEB_VIEW_REGISTER_MESSAGE_HANDLER_FOR_NEXT_LOAD", "next-load" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("EphyWebViewMessageHandlerScope"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* Generated data ends here */

