/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __EPHY_WEBAPP_PROVIDER_GENERATED_H__
#define __EPHY_WEBAPP_PROVIDER_GENERATED_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Epiphany.WebAppProvider */

#define EPHY_TYPE_WEB_APP_PROVIDER (ephy_web_app_provider_get_type ())
#define EPHY_WEB_APP_PROVIDER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_WEB_APP_PROVIDER, EphyWebAppProvider))
#define EPHY_IS_WEB_APP_PROVIDER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_WEB_APP_PROVIDER))
#define EPHY_WEB_APP_PROVIDER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), EPHY_TYPE_WEB_APP_PROVIDER, EphyWebAppProviderIface))

struct _EphyWebAppProvider;
typedef struct _EphyWebAppProvider EphyWebAppProvider;
typedef struct _EphyWebAppProviderIface EphyWebAppProviderIface;

struct _EphyWebAppProviderIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_get_installed_apps) (
    EphyWebAppProvider *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_install) (
    EphyWebAppProvider *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_url,
    const gchar *arg_name,
    const gchar *arg_install_token);

  gboolean (*handle_uninstall) (
    EphyWebAppProvider *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_desktop_file_id);

  guint  (*get_version) (EphyWebAppProvider *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (EphyWebAppProvider, g_object_unref)
#endif

GType ephy_web_app_provider_get_type (void);

GDBusInterfaceInfo *ephy_web_app_provider_interface_info (void);
guint ephy_web_app_provider_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void ephy_web_app_provider_complete_get_installed_apps (
    EphyWebAppProvider *object,
    GDBusMethodInvocation *invocation,
    const gchar *const *webapps);

void ephy_web_app_provider_complete_install (
    EphyWebAppProvider *object,
    GDBusMethodInvocation *invocation,
    const gchar *desktop_file_id);

void ephy_web_app_provider_complete_uninstall (
    EphyWebAppProvider *object,
    GDBusMethodInvocation *invocation);



/* D-Bus method calls: */
void ephy_web_app_provider_call_get_installed_apps (
    EphyWebAppProvider *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean ephy_web_app_provider_call_get_installed_apps_finish (
    EphyWebAppProvider *proxy,
    gchar *** out_webapps,
    GAsyncResult *res,
    GError **error);

gboolean ephy_web_app_provider_call_get_installed_apps_sync (
    EphyWebAppProvider *proxy,
    gchar *** out_webapps,
    GCancellable *cancellable,
    GError **error);

void ephy_web_app_provider_call_install (
    EphyWebAppProvider *proxy,
    const gchar *arg_url,
    const gchar *arg_name,
    const gchar *arg_install_token,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean ephy_web_app_provider_call_install_finish (
    EphyWebAppProvider *proxy,
    gchar ** out_desktop_file_id,
    GAsyncResult *res,
    GError **error);

gboolean ephy_web_app_provider_call_install_sync (
    EphyWebAppProvider *proxy,
    const gchar *arg_url,
    const gchar *arg_name,
    const gchar *arg_install_token,
    gchar ** out_desktop_file_id,
    GCancellable *cancellable,
    GError **error);

void ephy_web_app_provider_call_uninstall (
    EphyWebAppProvider *proxy,
    const gchar *arg_desktop_file_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean ephy_web_app_provider_call_uninstall_finish (
    EphyWebAppProvider *proxy,
    GAsyncResult *res,
    GError **error);

gboolean ephy_web_app_provider_call_uninstall_sync (
    EphyWebAppProvider *proxy,
    const gchar *arg_desktop_file_id,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
guint ephy_web_app_provider_get_version (EphyWebAppProvider *object);
void ephy_web_app_provider_set_version (EphyWebAppProvider *object, guint value);


/* ---- */

#define EPHY_TYPE_WEB_APP_PROVIDER_PROXY (ephy_web_app_provider_proxy_get_type ())
#define EPHY_WEB_APP_PROVIDER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_WEB_APP_PROVIDER_PROXY, EphyWebAppProviderProxy))
#define EPHY_WEB_APP_PROVIDER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), EPHY_TYPE_WEB_APP_PROVIDER_PROXY, EphyWebAppProviderProxyClass))
#define EPHY_WEB_APP_PROVIDER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_WEB_APP_PROVIDER_PROXY, EphyWebAppProviderProxyClass))
#define EPHY_IS_WEB_APP_PROVIDER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_WEB_APP_PROVIDER_PROXY))
#define EPHY_IS_WEB_APP_PROVIDER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_WEB_APP_PROVIDER_PROXY))

typedef struct _EphyWebAppProviderProxy EphyWebAppProviderProxy;
typedef struct _EphyWebAppProviderProxyClass EphyWebAppProviderProxyClass;
typedef struct _EphyWebAppProviderProxyPrivate EphyWebAppProviderProxyPrivate;

struct _EphyWebAppProviderProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  EphyWebAppProviderProxyPrivate *priv;
};

struct _EphyWebAppProviderProxyClass
{
  GDBusProxyClass parent_class;
};

GType ephy_web_app_provider_proxy_get_type (void);

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (EphyWebAppProviderProxy, g_object_unref)
#endif

void ephy_web_app_provider_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
EphyWebAppProvider *ephy_web_app_provider_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
EphyWebAppProvider *ephy_web_app_provider_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void ephy_web_app_provider_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
EphyWebAppProvider *ephy_web_app_provider_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
EphyWebAppProvider *ephy_web_app_provider_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define EPHY_TYPE_WEB_APP_PROVIDER_SKELETON (ephy_web_app_provider_skeleton_get_type ())
#define EPHY_WEB_APP_PROVIDER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_WEB_APP_PROVIDER_SKELETON, EphyWebAppProviderSkeleton))
#define EPHY_WEB_APP_PROVIDER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), EPHY_TYPE_WEB_APP_PROVIDER_SKELETON, EphyWebAppProviderSkeletonClass))
#define EPHY_WEB_APP_PROVIDER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_WEB_APP_PROVIDER_SKELETON, EphyWebAppProviderSkeletonClass))
#define EPHY_IS_WEB_APP_PROVIDER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_WEB_APP_PROVIDER_SKELETON))
#define EPHY_IS_WEB_APP_PROVIDER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_WEB_APP_PROVIDER_SKELETON))

typedef struct _EphyWebAppProviderSkeleton EphyWebAppProviderSkeleton;
typedef struct _EphyWebAppProviderSkeletonClass EphyWebAppProviderSkeletonClass;
typedef struct _EphyWebAppProviderSkeletonPrivate EphyWebAppProviderSkeletonPrivate;

struct _EphyWebAppProviderSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  EphyWebAppProviderSkeletonPrivate *priv;
};

struct _EphyWebAppProviderSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType ephy_web_app_provider_skeleton_get_type (void);

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (EphyWebAppProviderSkeleton, g_object_unref)
#endif

EphyWebAppProvider *ephy_web_app_provider_skeleton_new (void);


G_END_DECLS

#endif /* __EPHY_WEBAPP_PROVIDER_GENERATED_H__ */
