
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "ephy-link.h" */

GType ephy_link_flags_get_type (void);
#define EPHY_TYPE_LINK_FLAGS (ephy_link_flags_get_type())

/* enumerations from "ephy-shell.h" */

GType ephy_new_tab_flags_get_type (void);
#define EPHY_TYPE_NEW_TAB_FLAGS (ephy_new_tab_flags_get_type())

GType ephy_startup_mode_get_type (void);
#define EPHY_TYPE_STARTUP_MODE (ephy_startup_mode_get_type())

/* enumerations from "ephy-window.h" */

GType ephy_window_chrome_get_type (void);
#define EPHY_TYPE_WINDOW_CHROME (ephy_window_chrome_get_type())

G_END_DECLS

/* Generated data ends here */

