
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "ephy-download.h" */

GType ephy_download_action_type_get_type (void);
#define EPHY_TYPE_DOWNLOAD_ACTION_TYPE (ephy_download_action_type_get_type())

/* enumerations from "ephy-embed-shell.h" */

GType ephy_embed_shell_mode_get_type (void);
#define EPHY_TYPE_EMBED_SHELL_MODE (ephy_embed_shell_mode_get_type())

/* enumerations from "ephy-search-entry.h" */

GType ephy_find_result_get_type (void);
#define EPHY_TYPE_FIND_RESULT (ephy_find_result_get_type())

/* enumerations from "ephy-web-view.h" */

GType ephy_web_view_navigation_flags_get_type (void);
#define EPHY_TYPE_WEB_VIEW_NAVIGATION_FLAGS (ephy_web_view_navigation_flags_get_type())

GType ephy_web_view_document_type_get_type (void);
#define EPHY_TYPE_WEB_VIEW_DOCUMENT_TYPE (ephy_web_view_document_type_get_type())

GType ephy_web_view_error_page_get_type (void);
#define EPHY_TYPE_WEB_VIEW_ERROR_PAGE (ephy_web_view_error_page_get_type())

GType ephy_web_view_message_handler_get_type (void);
#define EPHY_TYPE_WEB_VIEW_MESSAGE_HANDLER (ephy_web_view_message_handler_get_type())

GType ephy_web_view_message_handler_scope_get_type (void);
#define EPHY_TYPE_WEB_VIEW_MESSAGE_HANDLER_SCOPE (ephy_web_view_message_handler_scope_get_type())

G_END_DECLS

/* Generated data ends here */

